==> sirikata-0.0.4-mac.tar.gz: sirikata_mac/include/sirikata/core/sync/TimeSyncServer.hpp <==
/*  Sirikata
 *  TimeSyncServer.hpp
 *
 *  Copyright (c) 2010, Ewen Cheslack-Postava
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are
 *  met:
 *  * Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  * Neither the name of Sirikata nor the names of its contributors may
 *    be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _SIRIKATA_CORE_SYNC_TIME_SYNC_SERVER_HPP_
#define _SIRIKATA_CORE_SYNC_TIME_SYNC_SERVER_HPP_

#include <sirikata/core/service/Context.hpp>
#include <sirikata/core/odp/Service.hpp>

namespace Sirikata {

/** TimeSyncServer implements the server for a simple time synchronization
 *  protocol. You give it a Context to get time information and it returns the
 *  payload for a response message -- simply package it up in a container frame
 *  and send it back to the client.
 */
class SIRIKATA_EXPORT TimeSyncServer {
public:
    TimeSyncServer(Context* ctx);
    ~TimeSyncServer();

    String getResponse(MemoryReference payload);
private:
    Context* mContext;
}; // class TimeSyncServer

} // namespace Sirikata

#endif //_SIRIKATA_CORE_SYNC_TIME_SYNC_SERVER_HPP_

==> sirikata-0.0.21-pre1-mac.tar.gz: sirikata_mac/include/sirikata/core/sync/TimeSyncServer.hpp <==
/*  Sirikata
 *  TimeSyncServer.hpp
 *
 *  Copyright (c) 2010, Ewen Cheslack-Postava
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are
 *  met:
 *  * Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  * Neither the name of Sirikata nor the names of its contributors may
 *    be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _SIRIKATA_CORE_SYNC_TIME_SYNC_SERVER_HPP_
#define _SIRIKATA_CORE_SYNC_TIME_SYNC_SERVER_HPP_

#include <sirikata/core/service/Context.hpp>
#include <sirikata/core/ohdp/Service.hpp>

namespace Sirikata {

/** TimeSyncServer implements the server for a simple time synchronization
 *  protocol. You give it a Context to get time information and it returns the
 *  payload for a response message -- simply package it up in a container frame
 *  and send it back to the client.
 */
class SIRIKATA_EXPORT TimeSyncServer {
public:
    TimeSyncServer(Context* ctx, OHDP::Service* ohdp);
    ~TimeSyncServer();
private:
    void handleMessage(const OHDP::Endpoint& src, const OHDP::Endpoint& dst, MemoryReference payload);

    Context* mContext;
    OHDP::Port* mPort;
}; // class TimeSyncServer

} // namespace Sirikata

#endif //_SIRIKATA_CORE_SYNC_TIME_SYNC_SERVER_HPP_
